@@ -18,6 +18,9 @@
 Blank namespace package.
 """
 
-__import__('pkg_resources').declare_namespace(__name__)
+
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 
 # End of file
